import sys

# from slai_cli.main import main


if __name__ == "__main__":
    sys.exit(main())
